==> spip_4.0.4.orig.tar.xz: plugins-dist/sites/lang/sites_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'In attesa',
	'articles_meme_auteur' => 'Tutti gli articoli per questo autore',
	'articles_off' => 'Bloccato',
	'articles_publie' => 'Pubblicato',
	'articles_refuse' => 'Cancellato',
	'articles_tous' => 'Tutto',
	'aucun_article_syndic' => 'Nessun articoli sindacato',
	'avis_echec_syndication_01' => 'La syndication è fallita: il backend indicato è indecifrabile o non propone alcun articolo.',
	'avis_echec_syndication_02' => 'La syndication è fallita: impossibile accedere al backend di questo sito.',
	'avis_site_introuvable' => 'Sito introvabile',
	'avis_site_syndique_probleme' => 'Attenzione: si è verificato un errore nella syndication del sito; il sistema è temporaneamente fuori uso. Verifica l’indirizzo del file per la syndication di questo sito (<b>@url_syndic@</b>) e prova nuovamente a recuperare le informazioni remote.',
	'avis_sites_probleme_syndication' => 'Si sono verificati alcuni problemi nella syndication di questi siti',
	'avis_sites_syndiques_probleme' => 'Si sono verificati alcuni problemi nella syndication di questi siti',

	// B
	'bouton_exporter' => 'Esporta',
	'bouton_importer' => 'Importa',
	'bouton_radio_modere_posteriori' => 'moderato a posteriori',
	'bouton_radio_modere_priori' => 'moderato a priori',
	'bouton_radio_non_syndication' => 'Nessuna syndication',
	'bouton_radio_syndication' => 'Syndication:',

	// C
	'confirmer_purger_syndication' => 'Sei sicuro di voler cancellare tutti gli articoli sindacati dal sito web?',

	// E
	'entree_adresse_fichier_syndication' => 'Indirizzo del file di syndication:',
	'entree_adresse_site' => '<b>Indirizzo del sito</b> [Obbligatorio]',
	'entree_description_site' => 'Descrizione del sito',
	'erreur_fichier_format_inconnu' => 'Il formato del file @fichier@ non è supportato.',
	'erreur_fichier_incorrect' => 'Impossibiole leggere il file.',
	'erreur_methode_syndication_inconnue' => 'Metodo di syndication @methode@ sconosciuto',

	// F
	'form_prop_nom_site' => 'Nome del sito',

	// I
	'icone_article_syndic' => 'Articolo sindacato',
	'icone_articles_syndic' => 'Articolo sindacato',
	'icone_controler_syndication' => 'Pubblicazione degli articoli sindacati',
	'icone_modifier_site' => 'Modifica il sito',
	'icone_referencer_nouveau_site' => 'Inserisci un nuovo sito in repertorio',
	'icone_site_reference' => 'Sito referenziato',
	'icone_supprimer_article' => 'Cancella questo articolo',
	'icone_supprimer_articles' => 'Cancella questi articoli',
	'icone_valider_article' => 'Conferma questo articolo',
	'icone_valider_articles' => 'Conferma questo articolo',
	'icone_voir_sites_references' => 'Vedi i siti in repertorio',
	'info_1_article_syndique' => '1 articolo in syndication',
	'info_1_site' => '1 sito',
	'info_1_site_importe' => '1 sito è stato importato',
	'info_a_valider' => '[da convalidare]',
	'info_aucun_article_syndique' => 'Nessun articolo in syndication',
	'info_aucun_site' => 'Nessun sito',
	'info_aucun_site_importe' => 'Nessun sito è stato importato',
	'info_bloquer' => 'bloccare',
	'info_bloquer_lien' => 'bloccare questo link',
	'info_derniere_syndication' => 'L’ultima <em>syndication</em> di questo sito è stata effettuata il',
	'info_liens_syndiques_1' => 'link in syndication',
	'info_liens_syndiques_2' => 'sono in attesa di convalida.',
	'info_nb_articles_syndiques' => '@nb@ articoli in syndication',
	'info_nb_sites' => '@nb@ siti',
	'info_nb_sites_importes' => '@nb@ siti sono stati importati',
	'info_nom_site_2' => '<b>Nome del sito</b> [Obbligatorio]',
	'info_panne_site_syndique' => 'Il sito in syndication non funziona',
	'info_probleme_grave' => 'problema di',
	'info_question_proposer_site' => 'Chi può proporre i siti da citare?',
	'info_retablir_lien' => 'ripristinare questo link',
	'info_site_attente' => 'Sito Web in attesa di convalida',
	'info_site_propose' => 'Sito proposto il:',
	'info_site_reference' => 'Sito repertoriato in linea',
	'info_site_refuse' => 'Sito Web rifiutato',
	'info_site_syndique' => 'Questo è un sito in syndication...',
	'info_site_valider' => 'Siti da convalidare',
	'info_sites_referencer' => 'Inserisci un sito in repertorio',
	'info_sites_refuses' => 'I siti rifiutati',
	'info_statut_site_1' => 'Questo sito è:',
	'info_statut_site_2' => 'Pubblicato',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'Nel cestino',
	'info_syndication' => 'syndication:',
	'info_syndication_articles' => 'articolo/i',
	'item_bloquer_liens_syndiques' => 'Blocca i link in syndication per la convalida',
	'item_gerer_annuaire_site_web' => 'Gestisci un repertorio di siti Web',
	'item_non_bloquer_liens_syndiques' => 'Non bloccare i link provenienti da una syndication',
	'item_non_gerer_annuaire_site_web' => 'Disattiva il repertorio di siti Web',
	'item_non_utiliser_syndication' => 'Non attivare la syndication automatica',
	'item_utiliser_syndication' => 'Attiva la syndication automatica',

	// L
	'label_exporter_avec_mots_cles_1' => 'Esportazione delle parole chiave come tag',
	'label_exporter_id_parent' => 'Esportare i siti web della sezione',
	'label_exporter_publie_seulement_1' => 'Esporta solo i siti web pubblicati',
	'label_fichier_import' => 'File HTML',
	'label_importer_les_tags_1' => 'Importa i tag come parole chiave',
	'label_importer_statut_publie_1' => 'Pubblica automaticamente il sito',
	'lien_mise_a_jour_syndication' => 'Aggiorna adesso',
	'lien_nouvelle_recuperation' => 'Tenta nuovamente di ripristinare i dati',
	'lien_purger_syndication' => 'Cancella tutti gli articoli sindacati',

	// N
	'nombre_articles_syndic' => '@nb@ articoli sindacati',

	// S
	'statut_off' => 'Cancellato',
	'statut_prop' => 'Proposto',
	'statut_publie' => 'Pubblicato',
	'syndic_choix_moderation' => 'Come comportarsi con i prossimi link provenienti da questo sito?',
	'syndic_choix_oublier' => 'Come comportarsi con i link che non compaiono più nel file di syndication?',
	'syndic_choix_resume' => 'Alcuni siti diffondono il testo completo degli articoli. Nel caso esso sia disponibile desiderate metterlo in syndication:',
	'syndic_lien_obsolete' => 'link non più valido',
	'syndic_option_miroir' => 'bloccarli automaticamente',
	'syndic_option_oubli' => 'cancellarli (dopo @mois@ mesi)',
	'syndic_option_resume_non' => 'il contenuto completo degli articoli(in formato HTML)',
	'syndic_option_resume_oui' => 'un semplice riassunto (in formato testo)',
	'syndic_options' => 'Opzioni per la syndication:',

	// T
	'texte_expliquer_export_bookmarks' => 'È possibile esportare una lista di siti prefriti con il formato HTML, in modo da poterli poi importare nel vostro browser o in un servizio online',
	'texte_expliquer_import_bookmarks' => 'È possibile importare una lista segnalibri di siti in formato HTML , dal browser o da un servizio online di gestione dei segnalibri.',
	'texte_liens_sites_syndiques' => 'I link provenienti dai siti in syndication possono essere bloccati a priori. L’impostazione qui sotto indica i criteri predefiniti dei siti in syndication. In ogni caso sarà comunque possibile sbloccare singolarmente ogni collegamento oppure scegliere di bloccare tutti i collegamenti futuri da un sito particolare.',
	'texte_messages_publics' => 'Messaggi pubblici dell’articolo:',
	'texte_non_fonction_referencement' => 'Puoi non utilizzare questa funzione automatica, e indicare direttamente gli elementi riguardanti il sito...',
	'texte_referencement_automatique' => '<b>Inserimento automatizzato in repertorio</b><br />È possibile repertoriare rapidamente un sito Web indicandone qui sotto l’indirizzo URL, o l’indirizzo del file di syndication. SPIP recupererà automaticamente le informazioni riguardanti il sito (titolo, descrizione...).',
	'texte_referencement_automatique_verifier' => 'Controllare le informazioni fornite da <tt>@url@</tt> prima di registrare.',
	'texte_syndication' => 'Quando un sito Web lo permette, è possibile recuperarne automaticamente
la lista delle novità. A tal fine è necessario attivare la syndication.

<blockquote><i>Alcuni provider disattivano questa funzionalità; 
in questo caso, non potrai utilizzare la syndication del contenuto
RSS a partire dal tuo sito.</i></blockquote>',
	'titre_articles_syndiques' => 'Articoli in syndication raccolti da questo sito',
	'titre_dernier_article_syndique' => 'Ultimi articoli in syndication',
	'titre_exporter_bookmarks' => 'Esporta i segnalibri',
	'titre_importer_bookmarks' => 'Importa i segnalibri',
	'titre_importer_exporter_bookmarks' => 'Importa ed esporta i segnalibri',
	'titre_page_sites_tous' => 'I siti repertoriati',
	'titre_referencement_sites' => 'Repertorio di siti e syndication',
	'titre_site_numero' => 'SITO NUMERO:',
	'titre_sites_proposes' => 'I siti proposti',
	'titre_sites_references_rubrique' => 'I siti repertoriati in questa rubrica',
	'titre_sites_syndiques' => 'I siti in syndication',
	'titre_sites_tous' => 'I siti repertoriati',
	'titre_syndication' => 'Syndication di siti',
	'tout_voir' => 'Mostra tutti gli articoli sindacati',

	// U
	'un_article_syndic' => '1 articolo sindacato'
);

==> spip_4.1.5+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'In attesa',
	'articles_meme_auteur' => 'Tutti gli articoli per questo autore',
	'articles_off' => 'Bloccato',
	'articles_publie' => 'Pubblicato',
	'articles_refuse' => 'Cancellato',
	'articles_tous' => 'Tutto',
	'aucun_article_syndic' => 'Nessun articolo sindacato',
	'avis_echec_syndication_01' => 'La syndication è fallita: il backend indicato è indecifrabile o non propone alcun articolo.',
	'avis_echec_syndication_02' => 'La syndication è fallita: impossibile accedere al backend di questo sito.',
	'avis_site_introuvable' => 'Sito introvabile',
	'avis_site_syndique_probleme' => 'Attenzione: si è verificato un errore nella syndication del sito; il sistema è temporaneamente fuori uso. Verifica l’indirizzo del file per la syndication di questo sito (<b>@url_syndic@</b>) e prova nuovamente a recuperare le informazioni remote.',
	'avis_sites_probleme_syndication' => 'Si sono verificati alcuni problemi nella syndication di questi siti',
	'avis_sites_syndiques_probleme' => 'Si sono verificati alcuni problemi nella syndication di questi siti',

	// B
	'bouton_exporter' => 'Esporta',
	'bouton_importer' => 'Importa',
	'bouton_radio_modere_posteriori' => 'moderato a posteriori',
	'bouton_radio_modere_priori' => 'moderato a priori',
	'bouton_radio_non_syndication' => 'Nessuna syndication',
	'bouton_radio_syndication' => 'Syndication:',

	// C
	'confirmer_purger_syndication' => 'Sei sicuro di voler cancellare tutti gli articoli sindacati dal sito web?',

	// E
	'entree_adresse_fichier_syndication' => 'Indirizzo del file di syndication:',
	'entree_adresse_site' => '<b>Indirizzo del sito</b> [Obbligatorio]',
	'entree_description_site' => 'Descrizione del sito',
	'erreur_fichier_format_inconnu' => 'Il formato del file @fichier@ non è supportato.',
	'erreur_fichier_incorrect' => 'Impossibiole leggere il file.',
	'erreur_methode_syndication_inconnue' => 'Metodo di syndication @methode@ sconosciuto',

	// F
	'form_prop_nom_site' => 'Nome del sito',

	// I
	'icone_article_syndic' => 'Articolo sindacato',
	'icone_articles_syndic' => 'Articoli sindacati',
	'icone_controler_syndication' => 'Pubblicazione degli articoli sindacati',
	'icone_modifier_site' => 'Modifica il sito',
	'icone_referencer_nouveau_site' => 'Inserisci un nuovo sito in repertorio',
	'icone_site_reference' => 'Sito referenziato',
	'icone_supprimer_article' => 'Cancella questo articolo',
	'icone_supprimer_articles' => 'Cancella questi articoli',
	'icone_valider_article' => 'Conferma questo articolo',
	'icone_valider_articles' => 'Conferma questi articoli',
	'icone_voir_sites_references' => 'Vedi i siti in repertorio',
	'info_1_article_syndique' => '1 articolo in syndication',
	'info_1_site' => '1 sito',
	'info_1_site_importe' => '1 sito è stato importato',
	'info_a_valider' => '[da convalidare]',
	'info_aucun_article_syndique' => 'Nessun articolo in syndication',
	'info_aucun_site' => 'Nessun sito',
	'info_aucun_site_importe' => 'Nessun sito è stato importato',
	'info_bloquer' => 'bloccare',
	'info_bloquer_lien' => 'bloccare questo link',
	'info_derniere_syndication' => 'L’ultima <em>syndication</em> di questo sito è stata effettuata il',
	'info_liens_syndiques_1' => 'link in syndication',
	'info_liens_syndiques_2' => 'sono in attesa di convalida.',
	'info_nb_articles_syndiques' => '@nb@ articoli in syndication',
	'info_nb_sites' => '@nb@ siti',
	'info_nb_sites_importes' => '@nb@ siti sono stati importati',
	'info_nom_site_2' => '<b>Nome del sito</b> [Obbligatorio]',
	'info_panne_site_syndique' => 'Il sito in syndication non funziona',
	'info_probleme_grave' => 'problema di',
	'info_question_proposer_site' => 'Chi può proporre i siti da citare?',
	'info_retablir_lien' => 'ripristinare questo link',
	'info_site_attente' => 'Sito Web in attesa di convalida',
	'info_site_propose' => 'Sito proposto il:',
	'info_site_reference' => 'Sito repertoriato in linea',
	'info_site_refuse' => 'Sito Web rifiutato',
	'info_site_syndique' => 'Questo è un sito in syndication...',
	'info_site_valider' => 'Siti da convalidare',
	'info_sites_referencer' => 'Inserisci un sito in repertorio',
	'info_sites_refuses' => 'I siti rifiutati',
	'info_statut_site_1' => 'Questo sito è:',
	'info_statut_site_2' => 'Pubblicato',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'Nel cestino',
	'info_syndication' => 'syndication:',
	'info_syndication_articles' => 'articolo/i',
	'item_bloquer_liens_syndiques' => 'Blocca i link in syndication per la convalida',
	'item_gerer_annuaire_site_web' => 'Gestisci un repertorio di siti Web',
	'item_non_bloquer_liens_syndiques' => 'Non bloccare i link provenienti da una syndication',
	'item_non_gerer_annuaire_site_web' => 'Disattiva il repertorio di siti Web',
	'item_non_utiliser_syndication' => 'Non attivare la syndication automatica',
	'item_utiliser_syndication' => 'Attiva la syndication automatica',

	// L
	'label_exporter_avec_mots_cles_1' => 'Esportazione delle parole chiave come tag',
	'label_exporter_id_parent' => 'Esportare i siti web della sezione',
	'label_exporter_publie_seulement_1' => 'Esporta solo i siti web pubblicati',
	'label_fichier_import' => 'File HTML',
	'label_importer_les_tags_1' => 'Importa i tag come parole chiave',
	'label_importer_statut_publie_1' => 'Pubblica automaticamente il sito',
	'lien_mise_a_jour_syndication' => 'Aggiorna adesso',
	'lien_nouvelle_recuperation' => 'Tenta nuovamente di ripristinare i dati',
	'lien_purger_syndication' => 'Cancella tutti gli articoli sindacati',

	// N
	'nombre_articles_syndic' => '@nb@ articoli sindacati',

	// S
	'statut_off' => 'Cancellato',
	'statut_prop' => 'Proposto',
	'statut_publie' => 'Pubblicato',
	'syndic_choix_moderation' => 'Come comportarsi con i prossimi link provenienti da questo sito?',
	'syndic_choix_oublier' => 'Come comportarsi con i link che non compaiono più nel file di syndication?',
	'syndic_choix_resume' => 'Alcuni siti diffondono il testo completo degli articoli. Nel caso esso sia disponibile desiderate metterlo in syndication:',
	'syndic_lien_obsolete' => 'link non più valido',
	'syndic_option_miroir' => 'bloccarli automaticamente',
	'syndic_option_oubli' => 'cancellarli (dopo @mois@ mesi)',
	'syndic_option_resume_non' => 'il contenuto completo degli articoli(in formato HTML)',
	'syndic_option_resume_oui' => 'un semplice riassunto (in formato testo)',
	'syndic_options' => 'Opzioni per la syndication:',

	// T
	'texte_expliquer_export_bookmarks' => 'È possibile esportare una lista di siti prefriti con il formato HTML, in modo da poterli poi importare nel vostro browser o in un servizio online',
	'texte_expliquer_import_bookmarks' => 'È possibile importare una lista segnalibri di siti in formato HTML , dal browser o da un servizio online di gestione dei segnalibri.',
	'texte_liens_sites_syndiques' => 'I link provenienti dai siti in syndication possono essere bloccati a priori. L’impostazione qui sotto indica i criteri predefiniti dei siti in syndication. In ogni caso sarà comunque possibile sbloccare singolarmente ogni collegamento oppure scegliere di bloccare tutti i collegamenti futuri da un sito particolare.',
	'texte_messages_publics' => 'Messaggi pubblici dell’articolo:',
	'texte_non_fonction_referencement' => 'Puoi non utilizzare questa funzione automatica, e indicare direttamente gli elementi riguardanti il sito...',
	'texte_referencement_automatique' => '<b>Inserimento automatizzato in repertorio</b><br />È possibile repertoriare rapidamente un sito Web indicandone qui sotto l’indirizzo URL, o l’indirizzo del file di syndication. SPIP recupererà automaticamente le informazioni riguardanti il sito (titolo, descrizione...).',
	'texte_referencement_automatique_verifier' => 'Controllare le informazioni fornite da <tt>@url@</tt> prima di registrare.',
	'texte_syndication' => 'Quando un sito Web lo permette, è possibile recuperarne automaticamente
la lista delle novità. A tal fine è necessario attivare la syndication.

<blockquote><i>Alcuni provider disattivano questa funzionalità; 
in questo caso, non potrai utilizzare la syndication del contenuto
RSS a partire dal tuo sito.</i></blockquote>',
	'titre_articles_syndiques' => 'Articoli in syndication raccolti da questo sito',
	'titre_dernier_article_syndique' => 'Ultimi articoli in syndication',
	'titre_exporter_bookmarks' => 'Esporta i segnalibri',
	'titre_importer_bookmarks' => 'Importa i segnalibri',
	'titre_importer_exporter_bookmarks' => 'Importa ed esporta i segnalibri',
	'titre_page_sites_tous' => 'I siti repertoriati',
	'titre_referencement_sites' => 'Repertorio di siti e syndication',
	'titre_site_numero' => 'SITO NUMERO:',
	'titre_sites_non_syndiques' => 'Il sito non è in syndication',
	'titre_sites_proposes' => 'I siti proposti',
	'titre_sites_references_rubrique' => 'I siti repertoriati in questa rubrica',
	'titre_sites_syndiques' => 'I siti in syndication',
	'titre_sites_tous' => 'I siti repertoriati',
	'titre_syndication' => 'Syndication di siti',
	'tout_voir' => 'Mostra tutti gli articoli sindacati',

	// U
	'un_article_syndic' => '1 articolo sindacato'
);
